==> 0.1.0.tar.gz: lib/geoglyphs_icons_icons.dart <==
library flutter_jap_icons;

import 'package:flutter/widgets.dart';

class GeoglyphsData extends IconData {
  const GeoglyphsData(int code, {String fontFamily, String fontPackage})
      : super(code, fontFamily: fontFamily, fontPackage: fontPackage);
}

class GeoglyphsIcons {
  GeoglyphsIcons._();

  static const _kFontFam = 'GeoglyphsIcons';
  static const String _kFontPkg = 'flutter_jap_icons';

  /// Icon for turf-along
  static const IconData turf_along =
      GeoglyphsData(0xe800, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-bbox-polygon
  static const IconData turf_bbox_polygon =
      GeoglyphsData(0xe801, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-bezier
  static const IconData turf_bezier =
      GeoglyphsData(0xe802, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-buffer
  static const IconData turf_buffer =
      GeoglyphsData(0xe803, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-center
  static const IconData turf_center =
      GeoglyphsData(0xe804, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-centroid
  static const IconData turf_centroid =
      GeoglyphsData(0xe805, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-concave
  static const IconData turf_concave =
      GeoglyphsData(0xe806, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-convex
  static const IconData turf_convex =
      GeoglyphsData(0xe807, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-destination
  static const IconData turf_destination =
      GeoglyphsData(0xe808, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-envelope
  static const IconData turf_envelope =
      GeoglyphsData(0xe809, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-erased
  static const IconData turf_erased =
      GeoglyphsData(0xe80a, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-explode
  static const IconData turf_explode =
      GeoglyphsData(0xe80b, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-extent
  static const IconData turf_extent =
      GeoglyphsData(0xe80c, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-intersect
  static const IconData turf_intersect =
      GeoglyphsData(0xe80d, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-kinks
  static const IconData turf_kinks =
      GeoglyphsData(0xe80e, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-line-slice
  static const IconData turf_line_slice =
      GeoglyphsData(0xe80f, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-merge
  static const IconData turf_merge =
      GeoglyphsData(0xe810, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-midpoint
  static const IconData turf_midpoint =
      GeoglyphsData(0xe811, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-point-grid
  static const IconData turf_point_grid =
      GeoglyphsData(0xe812, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-point-on-line
  static const IconData turf_point_on_line =
      GeoglyphsData(0xe813, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-point-on-surface
  static const IconData turf_point_on_surface =
      GeoglyphsData(0xe814, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-simplify
  static const IconData turf_simplify =
      GeoglyphsData(0xe815, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-size
  static const IconData turf_size =
      GeoglyphsData(0xe816, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-square
  static const IconData turf_square =
      GeoglyphsData(0xe817, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-square-grid
  static const IconData turf_square_grid =
      GeoglyphsData(0xe818, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-tin
  static const IconData turf_tin =
      GeoglyphsData(0xe819, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-triangle-grid
  static const IconData turf_triangle_grid =
      GeoglyphsData(0xe81a, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-union
  static const IconData turf_union =
      GeoglyphsData(0xe81b, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for ui-earth-east
  static const IconData ui_earth_east =
      GeoglyphsData(0xe81c, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for ui-earth-west
  static const IconData ui_earth_west =
      GeoglyphsData(0xe81d, fontFamily: _kFontFam, fontPackage: _kFontPkg);
}

==> 0.2.0.tar.gz: lib/geoglyphs_icons_icons.dart <==
library flutter_jap_icons;

import 'package:flutter/widgets.dart';

/// IconData for GeoglyphsIcons
class GeoglyphsData extends IconData {
  const GeoglyphsData(int code, {String? fontFamily, String? fontPackage})
      : super(code, fontFamily: fontFamily, fontPackage: fontPackage);
}

/// Class to generate GeoglyphsIcons
class GeoglyphsIcons {
  GeoglyphsIcons._();

  static const String? _kFontFam = 'GeoglyphsIcons';
  static const String? _kFontPkg = 'flutter_jap_icons';

  /// Icon for turf-along
  static const IconData turf_along =
      GeoglyphsData(0xe800, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-bbox-polygon
  static const IconData turf_bbox_polygon =
      GeoglyphsData(0xe801, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-bezier
  static const IconData turf_bezier =
      GeoglyphsData(0xe802, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-buffer
  static const IconData turf_buffer =
      GeoglyphsData(0xe803, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-center
  static const IconData turf_center =
      GeoglyphsData(0xe804, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-centroid
  static const IconData turf_centroid =
      GeoglyphsData(0xe805, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-concave
  static const IconData turf_concave =
      GeoglyphsData(0xe806, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-convex
  static const IconData turf_convex =
      GeoglyphsData(0xe807, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-destination
  static const IconData turf_destination =
      GeoglyphsData(0xe808, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-envelope
  static const IconData turf_envelope =
      GeoglyphsData(0xe809, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-erased
  static const IconData turf_erased =
      GeoglyphsData(0xe80a, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-explode
  static const IconData turf_explode =
      GeoglyphsData(0xe80b, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-extent
  static const IconData turf_extent =
      GeoglyphsData(0xe80c, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-intersect
  static const IconData turf_intersect =
      GeoglyphsData(0xe80d, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-kinks
  static const IconData turf_kinks =
      GeoglyphsData(0xe80e, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-line-slice
  static const IconData turf_line_slice =
      GeoglyphsData(0xe80f, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-merge
  static const IconData turf_merge =
      GeoglyphsData(0xe810, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-midpoint
  static const IconData turf_midpoint =
      GeoglyphsData(0xe811, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-point-grid
  static const IconData turf_point_grid =
      GeoglyphsData(0xe812, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-point-on-line
  static const IconData turf_point_on_line =
      GeoglyphsData(0xe813, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-point-on-surface
  static const IconData turf_point_on_surface =
      GeoglyphsData(0xe814, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-simplify
  static const IconData turf_simplify =
      GeoglyphsData(0xe815, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-size
  static const IconData turf_size =
      GeoglyphsData(0xe816, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-square
  static const IconData turf_square =
      GeoglyphsData(0xe817, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-square-grid
  static const IconData turf_square_grid =
      GeoglyphsData(0xe818, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-tin
  static const IconData turf_tin =
      GeoglyphsData(0xe819, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-triangle-grid
  static const IconData turf_triangle_grid =
      GeoglyphsData(0xe81a, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for turf-union
  static const IconData turf_union =
      GeoglyphsData(0xe81b, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for ui-earth-east
  static const IconData ui_earth_east =
      GeoglyphsData(0xe81c, fontFamily: _kFontFam, fontPackage: _kFontPkg);

  /// Icon for ui-earth-west
  static const IconData ui_earth_west =
      GeoglyphsData(0xe81d, fontFamily: _kFontFam, fontPackage: _kFontPkg);
}
